package com.example.catchTheLetters.service;

import com.example.catchTheLetters.model.dto.LoginDto;
import com.example.catchTheLetters.model.dto.RegisterDto;
import com.example.catchTheLetters.entity.User;
import com.example.catchTheLetters.model.vo.UserVo;
import com.example.catchTheLetters.utils.R;

/**
 * 认证服务接口
 *
 * @author spyn
 */
public interface AuthService {
    /**
     * 登录
     *
     * @param loginDto 登录信息
     * @return token
     */
    R<String> login(LoginDto loginDto);

    /**
     * 注销
     *
     * @param token token
     * @return 是否成功
     */
    boolean logout(String token);

    /**
     * 验证token
     *
     * @param token token
     * @return 用户信息（不可以包含密码）
     */
    User verify(String token);

    /**
     * 注册
     *
     * @param registerDto 注册信息
     * @return token
     */
    R<String> register(RegisterDto registerDto);

    /**
     * 获取用户信息
     *
     * @param id 用户id
     * @return 用户信息
     */
    User getUserInfo(String id);

    /**
     * 通过用户名获取信息
     *
     * @param username 用户名
     * @return 用户信息
     */
    User getUserByName(String username);

    /**
     * 用户信息修改
     *
     * @param user 用户信息
     * @param token token
     * @return 新的用户信息
     */
    R<UserVo> update(User user, String token);
}
