package com.example.catchTheLetters.utils;

import com.auth0.jwt.JWT;
import com.auth0.jwt.JWTCreator;
import com.auth0.jwt.algorithms.Algorithm;
import com.auth0.jwt.exceptions.TokenExpiredException;
import com.auth0.jwt.interfaces.Claim;
import com.auth0.jwt.interfaces.DecodedJWT;
import com.example.catchTheLetters.constant.CommonConstant;
import org.springframework.stereotype.Component;

import java.util.Calendar;
import java.util.Date;
import java.util.Map;

/**
 * @author 慕华
 * @date 2024/4/8
 * @Version 1.0
 * @description
 */
@Component
public class JwtUtil {
    public static final Integer EXPIRE_TIME = 1; // 1天

    /**
     * 生成token
     *
     * @param map     传入map
     * @param expired token存储时间
     * @return token
     */
    public static String getToken(Map<String, String> map, Integer expired) {
        Calendar instance = Calendar.getInstance();
        //设置过期时间单位：天
        instance.add(Calendar.DATE, expired);
        //创建JWT builder
        JWTCreator.Builder builder = JWT.create();
        //payload
        map.forEach(builder::withClaim);
        //制定令牌过期时间
        return builder.withExpiresAt(instance.getTime())
                //sign
                .sign(Algorithm.HMAC256(CommonConstant.TOKEN_SECRET));
    }

    /**
     * 验证token合法性 || 获取token信息方法
     *
     * @param token 传入token
     * @return
     */
    public static DecodedJWT verify(String token) {
        return JWT.require(Algorithm.HMAC256(CommonConstant.TOKEN_SECRET)).build().verify(token);
    }

    /**
     * 获取payload
     *
     * @param token 传入token
     * @return 返回payload
     */
    public static Map<String, Claim> getPayload(String token) {
        Map<String, Claim> claims = null;
        try {
            claims = JWT.require(Algorithm.HMAC256(CommonConstant.TOKEN_SECRET)).build().verify(token).getClaims();
        } catch (Exception e) {
            e.printStackTrace();
        }
        try {
            return claims;
        } catch (NullPointerException e) {
            e.printStackTrace();
            return null;
        }
    }

    /**
     * 获取过期时间
     */
    public static Date getExpiresAt(String token) {
        return verify(token).getExpiresAt();
    }

    /**
     * 判断token是否过期
     *
     * @return true:过期 false:没过期
     */
    public Boolean isTokenExpired(String token) {
        try {
            Date expiration = JwtUtil.getExpiresAt(token);
            return expiration.before(new Date());
        } catch (TokenExpiredException e) {
            return true;
        }
    }
}
